import { Capability, Browser, Options } from './types';
/**
 * Checkes if a given capability appears in a list of browsers matched from browerslist queries.
 *
 * @param allSupportedBrowsers - A list of browsers matched from browserslist queries.
 * @param capability - A capability to check against the given list of supported browsers.
 * @returns Whether the capability matches a supported browser.
 */
export declare function matchCapability(allSupportedBrowsers: Browser[], capability: Capability): boolean;
/**
 * Filters a given list of capabilites using the a list of supported browsers and include/exclude options.
 *
 * @param allCapabilities - A list of capabilites from BrowserStack's API.
 * @param allSupportedBrowsers - A list of browsers matched from browserslist queries.
 * @param options - The options to use when filtering capabilities.
 * @returns The given list of all capabilities filtered using the given supported browsers and options.
 */
export declare function filterCapabilities(allCapabilities: Capability[], allSupportedBrowsers: Browser[], options?: Options): Capability[];
/**
 * Gets a list of all possible capabilites for a given account.
 *
 * @param username - A BrowserStack account username to authenticate a BrowserStack REST API request.
 * @param accessKey - A BrowerStack account access key to authenticate a BrowserStack REST API request.
 * @returns The JSON response from the BrowserStack REST API Request.
 */
export declare function getAllCapabilities(username: string, accessKey: string): Promise<Capability[]>;
