"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.getAllCapabilities = exports.filterCapabilities = exports.matchCapability = void 0;
var types_1 = require("./types");
var helpers_1 = require("./helpers");
var node_fetch_1 = __importDefault(require("node-fetch"));
/**
 * Checkes if a given capability appears in a list of browsers matched from browerslist queries.
 *
 * @param allSupportedBrowsers - A list of browsers matched from browserslist queries.
 * @param capability - A capability to check against the given list of supported browsers.
 * @returns Whether the capability matches a supported browser.
 */
function matchCapability(allSupportedBrowsers, capability) {
    for (var _i = 0, allSupportedBrowsers_1 = allSupportedBrowsers; _i < allSupportedBrowsers_1.length; _i++) {
        var supported = allSupportedBrowsers_1[_i];
        if (supported.browser === capability.browser &&
            supported.browser_version === capability.browser_version) {
            return true;
        }
    }
    return false;
}
exports.matchCapability = matchCapability;
/**
 * Filters a given list of capabilites using the a list of supported browsers and include/exclude options.
 *
 * @param allCapabilities - A list of capabilites from BrowserStack's API.
 * @param allSupportedBrowsers - A list of browsers matched from browserslist queries.
 * @param options - The options to use when filtering capabilities.
 * @returns The given list of all capabilities filtered using the given supported browsers and options.
 */
function filterCapabilities(allCapabilities, allSupportedBrowsers, options) {
    return allCapabilities.filter(function (capability) {
        return helpers_1.filter(capability.browser, options === null || options === void 0 ? void 0 : options.browsers) &&
            helpers_1.filter(capability.os, options === null || options === void 0 ? void 0 : options.operatingSystems) &&
            helpers_1.filter(capability.os_version, options === null || options === void 0 ? void 0 : options.operatingSystemVersion) &&
            matchCapability(allSupportedBrowsers, capability);
    });
}
exports.filterCapabilities = filterCapabilities;
/**
 * Gets a list of all possible capabilites for a given account.
 *
 * @param username - A BrowserStack account username to authenticate a BrowserStack REST API request.
 * @param accessKey - A BrowerStack account access key to authenticate a BrowserStack REST API request.
 * @returns The JSON response from the BrowserStack REST API Request.
 */
function getAllCapabilities(username, accessKey) {
    return __awaiter(this, void 0, void 0, function () {
        var response;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, node_fetch_1["default"]("https://" + username + ":" + accessKey + "@api.browserstack.com/automate/browsers.json")];
                case 1:
                    response = _a.sent();
                    if (!response.ok) {
                        throw new types_1.ResponseError(response.statusText, response.status);
                    }
                    return [4 /*yield*/, response.json()];
                case 2: return [2 /*return*/, _a.sent()];
            }
        });
    });
}
exports.getAllCapabilities = getAllCapabilities;
