"use strict";
exports.__esModule = true;
exports.arraysEqual = exports.xor = exports.filter = void 0;
/**
 * Determines whether a given value should be filtered out or not, using an array of valid include values and invalid exclude values.
 *
 * @param value - The value to check against the include and exclude filters.
 * @param filters - The filters to check the given value against, include and exclude.
 * @returns Whether the value should be filtered out.
 */
function filter(value, filters) {
    var _a = filters || {}, _b = _a.include, include = _b === void 0 ? [] : _b, _c = _a.exclude, exclude = _c === void 0 ? [] : _c;
    return ((!include.length || include.includes(value)) &&
        (!exclude.length || !exclude.includes(value)));
}
exports.filter = filter;
/**
 * Exclusive OR.
 *
 * @param lhs - Left hand side.
 * @param rhs - Right hand side.
 * @returns Whether the lhs is true and rhs isn't or rhs is true and lhs isn't.
 */
function xor(lhs, rhs) {
    return (lhs && !rhs) || (!lhs && rhs);
}
exports.xor = xor;
/**
 * Check if the value of 2 arrays are equal.
 *
 * @param array1 - First array to compare.
 * @param array2 - Second array to compare.
 * @returns Whether the arrays are equal by value.
 */
function arraysEqual(array1, array2) {
    if (array1.length !== array2.length) {
        return false;
    }
    for (var index in array1) {
        var item1 = array1[index];
        var item2 = array2[index];
        var type1 = typeof item1;
        var type2 = typeof item2;
        if (type1 !== type2) {
            return false;
        }
        if (type1 === 'object') {
            var isArray1 = Array.isArray(item1);
            var isArray2 = Array.isArray(item2);
            if (isArray1 && isArray2 && !arraysEqual(item1, item2)) {
                return false;
            }
            else if (xor(isArray1, isArray2)) {
                return false;
                // Not the most efficient way to do this, but this is currently only being used for testing.
            }
            else if (JSON.stringify(item1) !== JSON.stringify(item2)) {
                return false;
            }
        }
        else if (item1 !== item2) {
            return false;
        }
    }
    return true;
}
exports.arraysEqual = arraysEqual;
